@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2101';
+our $VERSION = '0.2102';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -494,7 +494,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2101
+version 0.2102
 
 =head1 SYNOPSIS
 
@@ -556,6 +556,28 @@ SYNOPSIS.
 A prisoner's dilemma tournament of different strategies, ala Axelrod, can be
 found the the F<eg/> directory of this distribution.
 
+A prisoner's dilemma, where Blue is the row player, Red is the column player,
+and T > R > P > S is:
+
+    \ Red  |           |
+      \    | Cooperate | Defect
+ Blue   \  |           |
+ --------------------------------
+           | \   R     | \   T
+ Cooperate |   \       |   \
+           | R   \     | S   \
+ --------------------------------
+           | \   S     | \   P
+ Defect    |   \       |   \
+           | T   \     | P   \
+
+And in this implementation that would be:
+
+ $g = Game::Theory::TwoPersonMatrix->new(
+    payoff1 => [ [ -1, -3 ], [ 0, -2 ] ],   # Blue: [ R, S ], [ T, P ]
+    payoff2 => [ [ -1,  0 ], [-3, -2 ] ],   # Red:  [ R, T ], [ S, P ]
+ );
+
 =head1 METHODS
 
 =head2 new()
